@@ -11,14 +11,14 @@ use panic_halt as _;
 use stm32f4xx_hal as hal;
 
 use crate::hal::{
-    gpio::{gpioa, Output, PushPull},
+    gpio::{self, Output, PushPull},
     pac::{interrupt, Interrupt, Peripherals, TIM2},
     prelude::*,
-    timer::{CounterUs, Event, Timer},
+    timer::{CounterUs, Event},
 };
 
 use core::cell::RefCell;
-use cortex_m::{asm::wfi, interrupt::Mutex};
+use cortex_m::interrupt::Mutex;
 use cortex_m_rt::entry;
 
 // NOTE You can uncomment 'hprintln' here and in the code below for a bit more
@@ -28,8 +28,8 @@ use cortex_m_rt::entry;
 //use cortex_m_semihosting::hprintln;
 
 // A type definition for the GPIO pin to be used for our LED
-// For the onboard nucleo LED, use gpioa::PA5 or gpiob::PB13 depending your model
-type LedPin = gpioa::PA5<Output<PushPull>>;
+// For the onboard nucleo LED, use PA5 or PB13 depending your model
+type LedPin = gpio::PA5<Output<PushPull>>;
 
 // Make LED pin globally available
 static G_LED: Mutex<RefCell<Option<LedPin>>> = Mutex::new(RefCell::new(None));
@@ -67,7 +67,7 @@ fn main() -> ! {
     let dp = Peripherals::take().unwrap();
 
     let rcc = dp.RCC.constrain();
-    let clocks = rcc.cfgr.sysclk(16.mhz()).pclk1(8.mhz()).freeze();
+    let clocks = rcc.cfgr.sysclk(16.MHz()).pclk1(8.MHz()).freeze();
 
     // Configure PA5 pin to blink LED
     let gpioa = dp.GPIOA.split();
@@ -78,11 +78,11 @@ fn main() -> ! {
     cortex_m::interrupt::free(|cs| *G_LED.borrow(cs).borrow_mut() = Some(led));
 
     // Set up a timer expiring after 1s
-    let mut timer = Timer::new(dp.TIM2, &clocks).counter();
+    let mut timer = dp.TIM2.counter(&clocks);
     timer.start(1.secs()).unwrap();
 
     // Generate an interrupt when the timer expires
-    timer.listen(Event::TimeOut);
+    timer.listen(Event::Update);
 
     // Move the timer into our global storage
     cortex_m::interrupt::free(|cs| *G_TIM.borrow(cs).borrow_mut() = Some(timer));
@@ -92,7 +92,9 @@ fn main() -> ! {
         cortex_m::peripheral::NVIC::unmask(Interrupt::TIM2);
     }
 
+    #[allow(clippy::empty_loop)]
     loop {
-        wfi();
+        // Uncomment if you want to make controller sleep
+        // cortex_m::asm::wfi();
     }
 }
