@@ -59,7 +59,7 @@ use core::marker::PhantomData;
 mod alt;
 pub(crate) use alt::{Const, PinA, SetAlternate};
 mod convert;
-use convert::PinMode;
+pub use convert::PinMode;
 mod partially_erased;
 pub use partially_erased::{PEPin, PartiallyErasedPin};
 mod erased;
